PerTableData

Struct PerTableData 

struct PerTableData<T> {
Show 54 fields ankr: T, avar: T, base: T, cff: T, cff2: T, cbdt: T, cblc: T, colr: T, cpal: T, cmap: T, cvar: T, cvt: T, dsig: T, ebdt: T, eblc: T, feat: T, fpgm: T, fvar: T, gasp: T, gdef: T, glyf: T, gpos: T, gsub: T, gvar: T, hdmx: T, head: T, hhea: T, hmtx: T, hvar: T, ift: T, iftx: T, jstf: T, kern: T, kerx: T, loca: T, ltag: T, math: T, maxp: T, meta: T, morx: T, mvar: T, name: T, os2: T, post: T, prep: T, sbix: T, stat: T, svg: T, trak: T, varc: T, vhea: T, vmtx: T, vorg: T, vvar: T,
}
Holds some data for each possible table in a font.

Fields

ankr: T

Anchor point table.

avar: T

Axis variation table.

base: T

Baseline table.

cff: T

Compact font format table.

cff2: T

Compact font format 2.0 table.

cbdt: T

Color bitmap data table.

cblc: T

Color bitmap location table.

colr: T

Color table.

cpal: T

Color palette table.

cmap: T

Character to glyph mapping table.

cvar: T

CVT variations table.

cvt: T

Control value table.

dsig: T

Digital signature table.

ebdt: T

Embedded bitmap data table.

eblc: T

Embedded bitmap location data table.

feat: T

Font feature table.

fpgm: T

Font program table.

fvar: T

Font variations table.

gasp: T

Grid-fitting and scan-conversion procedure table.

gdef: T

Glyph definition table.

glyf: T

TrueType glyph data table.

gpos: T

Glyph positioning table.

gsub: T

Glyph substitution table.

gvar: T

Glyph variation table.

hdmx: T

Horizontal device metrics.

head: T

Font header table.

hhea: T

Horizontal header table.

hmtx: T

Horizontal metrics table.

hvar: T

Horizontal metrics variation table.

ift: T

Incremental font transfer table.

iftx: T

Incremental font transfer table.

jstf: T

Justification table.

kern: T

Kerning table.

kerx: T

Extended kerning table.

loca: T

Index to location table.

ltag: T

Language tag table.

math: T

Mathematical typesetting table.

maxp: T

Maximum profile table.

meta: T

Metadata table.

morx: T

Extended metamorphosis table.

mvar: T

Metrics variation table.

name: T

Naming table.

os2: T

OS/2 and Windows-specific metrics table.

post: T

PostScript information table.

prep: T

Control value program table.

sbix: T

Standard bitmap graphics table.

stat: T

Style attributes table.

svg: T

Scalable vector graphics table.

trak: T

Tracking table.

varc: T

Variable composite/component table.

vhea: T

Vertical header table.

vmtx: T

Vertical metrics table.

vorg: T

Vertical origin table.

vvar: T

Vertical metrics variation table.

Implementations

Source

impl<T> PerTableData<T>

fn init_all(&mut self, f: impl Fn(Tag, &mut T))

Calls f with the tag and associated data for each table.